@@ -20,6 +20,17 @@
 #define __M_RSS_H__
 
 #include <sys/types.h>
+#include <curl/curl.h>
+
+#define LIBMRSS_VERSION_STRING  "0.18.0"
+
+#define LIBMRSS_MAJOR_VERSION   0
+#define LIBMRSS_MINOR_VERSION   18
+#define LIBMRSS_MICRO_VERSION   0
+
+#ifdef  __cplusplus
+extern "C" {
+#endif
 
 typedef struct mrss_t mrss_t;
 typedef struct mrss_options_t mrss_options_t;
@@ -36,6 +47,7 @@ typedef enum {
   MRSS_OK = 0,			/**< No error */
   MRSS_ERR_POSIX,		/**< For the correct error, use errno */
   MRSS_ERR_PARSER,		/**< Parser error */
+  MRSS_ERR_DOWNLOAD,		/**< Download error */
   MRSS_ERR_VERSION,		/**< The RSS has a no compatible VERSION */
   MRSS_ERR_DATA			/**< The parameters are incorrect */
 } mrss_error_t;
@@ -363,7 +375,7 @@ struct mrss_t {
   /** For internal use only: */
   mrss_element_t element;
   int allocated;
-  void *c_locale;
+  int curl_error;
 
   /* Data: */
 
@@ -431,6 +443,11 @@ struct mrss_t {
   mrss_item_t *item;		/* R	R	R	R	R	*/
 
   mrss_tag_t *other_tags;
+
+#ifdef USE_LOCALE
+  void *c_locale;
+#endif
+
 };
 
 /** Data struct for any other tag out of the RSS namespace.
@@ -523,6 +540,20 @@ mrss_error_t	mrss_parse_url_with_options
 					 mrss_t **	mrss,
 					 mrss_options_t	* options);
 
+/**
+ * Like the previous function but with CURLcode error
+ * \param url The url to be parsed
+ * \param mrss the pointer to your data struct
+ * \param options a pointer to a options data struct. It can be NULL
+ * \param curlcode the error code from libcurl
+ * \return the error code
+ */
+mrss_error_t	mrss_parse_url_with_options_and_error
+					(char *		url,
+					 mrss_t **	mrss,
+					 mrss_options_t	* options,
+					 CURLcode *	curlcode);
+
 /** 
  * Parses a file and creates the data struct of the feed RSS url
  * \param file The file to be parsed
@@ -600,6 +631,13 @@ mrss_error_t	mrss_free		(mrss_generic_t	element);
  */
 char *		mrss_strerror		(mrss_error_t	err);
 
+/** 
+ * This function returns a static string with the description of curl code
+ * \param err the error code that you need as string
+ * \return a string. Don't free this string!
+ */
+char *		mrss_curl_strerror	(CURLcode	err);
+
 /**
  * This function returns the mrss_element_t of a mrss data struct.
  * \param element it is the element that you want check
@@ -634,6 +672,21 @@ mrss_error_t	mrss_get_last_modified_with_options
 					(char *		urlstring,
 					 time_t *	lastmodified,
 					 mrss_options_t * options);
+/**
+ * Like the previous function but with a CURLcode pointer.
+ *
+ * \param urlstring the url
+ * \param lastmodified is a pointer to a time_t struct. The return value can
+ * be 0 if the HEAD request does not return a Last-Modified value.
+ * \param options a pointer to a options struct
+ * \param curl_code it will contain the error code of libcurl
+ * \return the error code
+ */
+mrss_error_t	mrss_get_last_modified_with_options_and_error
+					(char *		urlstring,
+					 time_t *	lastmodified,
+					 mrss_options_t * options,
+					 CURLcode *	curl_code);
 
 /** EDIT FUNCTIONS **********************************************************/
 
@@ -807,6 +860,10 @@ mrss_options_t *
  */
 void		mrss_options_free	(mrss_options_t *options);
 
+#ifdef  __cplusplus
+}
+#endif
+
 #endif
 
 /* EOF */
