@@ -22,18 +22,35 @@
 # error Use configure; make; make install
 #endif
 
-#include "mrss_internal.h"
 #include "mrss.h"
+#include "mrss_internal.h"
 
 char *
-__mrss_download_file (nxml_t * nxml, char *fl, size_t * size)
+__mrss_download_file (nxml_t * nxml, char *fl, size_t * size,
+		      mrss_error_t * error, CURLcode * code)
 {
   char *buffer;
 
-  if (nxml_download_file (nxml, fl, &buffer, size) != NXML_OK)
-    return NULL;
+  if(code)
+    *code = CURLE_OK;
 
-  return buffer;
+  switch (nxml_download_file (nxml, fl, &buffer, size))
+    {
+    case NXML_OK:
+      return buffer;
+
+    case NXML_ERR_DOWNLOAD:
+
+      if(code)
+        *code = nxml_curl_error (nxml, NXML_ERR_DOWNLOAD);
+      
+      *error = MRSS_ERR_DOWNLOAD;
+      return NULL;
+
+    default:
+      *error = MRSS_ERR_POSIX;
+      return NULL;
+    }
 }
 
 /* EOF */
