@@ -22,8 +22,8 @@
 # error Use configure; make; make install
 #endif
 
-#include "mrss_internal.h"
 #include "mrss.h"
+#include "mrss_internal.h"
 
 static void
 __mrss_parse_tag_insert (mrss_tag_t ** where, mrss_tag_t * what)
@@ -152,12 +152,16 @@ __mrss_atom_prepare_date (mrss_t * data, char *datestr)
       stm.tm_year -= 1900;
       stm.tm_mon -= 1;
 
+#ifdef USE_LOCALE
       if (!data->c_locale
 	  && !(data->c_locale = newlocale (LC_ALL_MASK, "C", NULL)))
 	return NULL;
 
       strftime_l (datebuf, sizeof (datebuf), "%a, %d %b %Y %H:%M:%S %z", &stm,
 		  data->c_locale);
+#else
+      strftime (datebuf, sizeof (datebuf), "%a, %d %b %Y %H:%M:%S %z", &stm);
+#endif
 
       return strdup (datebuf);
     }
@@ -1074,12 +1078,20 @@ __mrss_parser (nxml_t * doc, mrss_t ** ret)
 mrss_error_t
 mrss_parse_url (char *url, mrss_t ** ret)
 {
-  return mrss_parse_url_with_options (url, ret, NULL);
+  return mrss_parse_url_with_options_and_error (url, ret, NULL, NULL);
 }
 
 mrss_error_t
 mrss_parse_url_with_options (char *url, mrss_t ** ret,
 			     mrss_options_t * options)
+{
+  return mrss_parse_url_with_options_and_error (url, ret, options, NULL);
+}
+
+mrss_error_t
+mrss_parse_url_with_options_and_error (char *url, mrss_t ** ret,
+				       mrss_options_t * options,
+				       CURLcode * code)
 {
   nxml_t *doc;
   mrss_error_t err;
@@ -1106,13 +1118,12 @@ mrss_parse_url_with_options (char *url, mrss_t ** ret,
       if (options->user_agent)
 	nxml_set_user_agent (doc, options->user_agent);
 
-      if (options->certfile)
-	nxml_set_certificate (doc, options->certfile, options->password,
-			      options->cacert, options->verifypeer);
+      nxml_set_certificate (doc, options->certfile, options->password,
+			    options->cacert, options->verifypeer);
     }
 
-  if (!(buffer = __mrss_download_file (doc, url, &size)))
-    return MRSS_ERR_POSIX;
+  if (!(buffer = __mrss_download_file (doc, url, &size, &err, code)))
+    return err;
 
   if (nxml_parse_buffer (doc, buffer, size) != NXML_OK)
     {
