@@ -22,8 +22,8 @@
 # error Use configure; make; make install
 #endif
 
-#include "mrss_internal.h"
 #include "mrss.h"
+#include "mrss_internal.h"
 
 static void
 __mrss_write_string (void (*func) (void *, char *, ...), void *obj, char *str)
@@ -880,7 +880,7 @@ __mrss_write_atom (mrss_t * mrss, void (*func) (void *, char *, ...),
 
       func (obj, ">");
       __mrss_write_string (func, obj, mrss->generator);
-      func (obj, "<generator>\n");
+      func (obj, "</generator>\n");
     }
 
   if (mrss->image_url)
